@@ -14,13 +14,14 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgspoint.h 13005 2010-03-05 12:28:08Z mhugent $ */
+/* $Id$ */
 
 #ifndef QGSPOINT_H
 #define QGSPOINT_H
 
 #include <iostream>
 #include <QString>
+#include <QPoint>
 
 /** \ingroup core
  * A class to represent a vector.
@@ -148,6 +149,10 @@ class CORE_EXPORT QgsPoint
     @note added in QGIS 1.5*/
     double sqrDistToSegment( double x1, double y1, double x2, double y2, QgsPoint& minDistPoint ) const;
 
+    /**Calculates azimut between this point and other one (clockwise in degree, starting from north)
+      @note: this function has been added in version 1.7*/
+    double azimuth( const QgsPoint& other );
+
     //! equality operator
     bool operator==( const QgsPoint &other );
 
