@@ -10,6 +10,7 @@ import os
 
 from ui_dialogBase import Ui_GdalToolsDialog as Ui_Dialog
 import GdalTools_utils as Utils
+from .. import resources_rc
 
 import os, platform
 
@@ -21,24 +22,19 @@ class GdalToolsBaseDialog(QDialog, Ui_Dialog):
       self.iface = iface
 
       self.process = QProcess(self)
-      gdalPath = Utils.getGdalPath()
-      if not gdalPath.isEmpty():
-          env = self.process.environment()
-          if env.isEmpty():
-            #env << "PATH=" + gdalPath
-            os.putenv( "PATH", str( gdalPath ) )
-          else:
-            if platform.system() == "Windows":
-              env.replaceInStrings( QRegExp( "^PATH=(.*)", Qt.CaseInsensitive ), "PATH=\\1;" + gdalPath )
-            else:
-              env.replaceInStrings( QRegExp( "^PATH=(.*)", Qt.CaseInsensitive ), "PATH=\\1:" + gdalPath )
-          self.process.setEnvironment( env )
+      Utils.setProcessEnvironment(self.process)
       self.connect(self.process, SIGNAL("error(QProcess::ProcessError)"), self.processError)
       self.connect(self.process, SIGNAL("finished(int, QProcess::ExitStatus)"), self.processFinished)
 
       self.setupUi(self)
       self.arguments = QStringList()
 
+      self.editCmdBtn.setIcon( QIcon(":/icons/edit.png") )
+      self.connect(self.editCmdBtn, SIGNAL("toggled(bool)"), self.editCommand)
+      self.resetCmdBtn.setIcon( QIcon(":/icons/reset.png") )
+      self.connect(self.resetCmdBtn, SIGNAL("clicked()"), self.resetCommand)
+      self.editCommand( False )
+
       self.connect(self.buttonBox, SIGNAL("rejected()"), self.reject)
       self.connect(self.buttonBox, SIGNAL("accepted()"), self.accept)
       self.connect(self.buttonBox, SIGNAL("helpRequested()"), self.help)
@@ -66,6 +62,32 @@ class GdalToolsBaseDialog(QDialog, Ui_Dialog):
       else:
         self.helpFileName = cmd + ".html"
 
+
+  def editCommand(self, enabled):
+      if not self.commandIsEnabled():
+        return
+      self.editCmdBtn.setChecked( enabled )
+      self.resetCmdBtn.setEnabled( enabled )
+      self.textEditCommand.setReadOnly( not enabled )
+      self.controlsWidget.setEnabled( not enabled )
+      self.emit( SIGNAL("refreshArgs()") )
+
+  def resetCommand(self):
+      if not self.commandIsEditable():
+        return
+      self.emit( SIGNAL("refreshArgs()") )
+
+  def commandIsEditable(self):
+      return self.commandIsEnabled() and self.editCmdBtn.isChecked()
+
+  def setCommandViewerEnabled(self, enable):
+      if not enable:
+        self.editCommand( False )
+      self.commandWidget.setEnabled( enable )
+
+  def commandIsEnabled(self):
+      return self.commandWidget.isEnabled()
+
   def reject(self):
       if self.process.state() != QProcess.NotRunning:
         ret = QMessageBox.warning(self, self.tr( "Warning" ), self.tr( "The command is still running. \nDo you want terminate it anyway?" ), QMessageBox.Yes | QMessageBox.No)
@@ -98,17 +120,14 @@ class GdalToolsBaseDialog(QDialog, Ui_Dialog):
         url = QUrl.fromLocalFile(helpPath + '/' + self.helpFileName)
       QDesktopServices.openUrl(url)
 
-  def setCommandViewerEnabled(self, enable):
-      self.textEditCommand.setEnabled( enable )
-
   # called when a value in the plugin widget interface changed
   def refreshArgs(self, args):
       self.arguments = args
 
-      if not self.textEditCommand.isEnabled():
-        self.textEditCommand.setText(self.command)
+      if not self.commandIsEnabled():
+        self.textEditCommand.setPlainText(self.command)
       else:
-        self.textEditCommand.setText(self.command + " " + Utils.escapeAndJoin(self.arguments))
+        self.textEditCommand.setPlainText(self.command + " " + Utils.escapeAndJoin(self.arguments))
 
   # enables the OK button
   def enableRun(self, enable = True):
@@ -116,19 +135,12 @@ class GdalToolsBaseDialog(QDialog, Ui_Dialog):
 
   # start the command execution
   def onRun(self):
-      self.process.start(self.command, self.arguments, QIODevice.ReadOnly)
       self.enableRun(False)
       self.setCursor(Qt.WaitCursor)
-
-      """
-      try:
-        print "Debug: " + self.command + " " + unicode(Utils.escapeAndJoin(self.arguments))
-      except UnicodeEncodeError:
-        try:
-          print "Debug: " + self.command + " " + unicode(Utils.escapeAndJoin(self.arguments)).encode('cp866', 'replace')
-        except:
-          print "Debug: " + self.command + " " + unicode(Utils.escapeAndJoin(self.arguments)).encode('ascii', 'replace')
-      """
+      if not self.commandIsEditable():
+        self.process.start(self.command, self.arguments, QIODevice.ReadOnly)
+      else:
+        self.process.start(self.textEditCommand.toPlainText(), QIODevice.ReadOnly)
 
   # stop the command execution
   def stop(self):
