@@ -528,6 +528,9 @@ class QgsPluginInstallerDialog(QDialog, Ui_QgsPluginInstallerDialogBase):
           n +=1
     self.setWindowTitle(self.tr("QGIS Python Plugin Installer") + self.tr(" - %d plugins available" % len(plugins.all())))
     self.buttonUpgradeAll.setEnabled( len(self.upgradeablePlugins) )
+
+    # initially, keep insert order
+    self.treePlugins.sortItems(100,Qt.AscendingOrder)
     
     # resize the columns
     for i in [0,1,2,3,4,5]:
@@ -537,8 +540,6 @@ class QgsPluginInstallerDialog(QDialog, Ui_QgsPluginInstallerDialogBase):
         self.treePlugins.setColumnWidth(i, 260)
     if self.treePlugins.columnWidth(3) > 560:
       self.treePlugins.setColumnWidth(3, 560)
-    # initially, keep order of inserting
-    self.treePlugins.sortItems(100,Qt.AscendingOrder)
 
 
   # ----------------------------------------- #
@@ -629,7 +630,7 @@ class QgsPluginInstallerDialog(QDialog, Ui_QgsPluginInstallerDialogBase):
           exec ("reload (%s)" % plugin["localdir"])
         except:
           pass
-      plugins.getAllInstalled()
+      plugins.getAllInstalled(testLoad=True)
       plugins.rebuild()
       plugin = plugins.all()[key]
       if not plugin["error"]:
